@@ -1,5 +1,5 @@
 cPoints=function(Input){
-  Locs=SpatialPointsDataFrame(cbind(Input[,2],Input[,1]),Input,proj4string=CRS("+proj=longlat +ellps=WGS84"))
+  Locs=SpatialPointsDataFrame(cbind(Input[,2],Input[,1]),Input,proj4string=CRS("+proj=longlat +datum=WGS84 +no_defs"))
   Locs=spTransform(Locs,CRS(CCAMLRp))
   tmp=coordinates(Locs)
   Locs$x=tmp[,1]
